package main

import (
	"fmt"
	"os"
	"strings"
	"datasmith/commands"
	"datasmith/config"
)

var version = "1.0.0"

func main() {
	config.LoadConfig()

	if len(os.Args) < 2 {
		commands.Help()
		return
	}

	command := os.Args[1]

	switch command {
	case "init":
		var name, dbType string
		args := os.Args[2:]
		for i := 0; i < len(args); i++ {
			arg := args[i]
			if arg == "--type" && i+1 < len(args) {
				dbType = args[i+1]
				i++ // Skip the next argument since it's the model value
			} else if !strings.HasPrefix(arg, "--") {
				name = arg
			}
		}
		if name == "" {
			fmt.Println("Usage: ds init <name> [--type <json_model>]")
			return
		}
		commands.InitProject(name, dbType)
		fmt.Println("Done. Now run 'ds add' to add a table to the database.")
	case "add":
		var tableName, model string
		args := os.Args[2:]
		for i := 0; i < len(args); i++ {
			arg := args[i]
			if arg == "--model" && i+1 < len(args) {
				model = args[i+1]
				i++ // Skip the next argument since it's the model value
			} else if !strings.HasPrefix(arg, "--") {
				tableName = arg
			}
		}
		if tableName == "" {
			fmt.Println("Usage: ds add <tablename> [--model <json_model>]")
			return
		}
		commands.Add(tableName, model)
	case "serve":
		commands.Serve()
	case "version":
		commands.Version(version)
	case "help":
		commands.Help()
	// TODO:  generate test data
	default:
		fmt.Printf("Unknown command: %s\n", command)
		commands.Help()
	}
}